
export type PropsTypes = {
    visible: boolean, //是否显示
    title?: string, //
    customClass?: string,
    useHead?: boolean,
    showCloseBtn?: boolean,
    shadowClose?: boolean,
}
export type EmitsTypes = {
    (e: 'update:visible', visible: boolean): void,
    (e: 'open'): void,
    (e: 'click'): void,
    (e: 'close', pos?: number | string): void,
}

export const useState = (props: PropsTypes, emits: EmitsTypes) => {
    const showing = ref(false)

    const handleShow = () => emits('open')

    const handleClose = (pos?: number | string) => {
        emits('close', pos)
        emits('update:visible', false)
    }

    const handleClick = () => emits('click')

    watch(
        () => props.visible, (val) => {
            showing.value = val;
            val ? handleShow() : handleClose()
        },
        { immediate: true }
    )

    return {
        showing,
        handleShow,
        handleClose,
        handleClick,
    }
}